@@ -27,7 +27,7 @@
 
 #include <pbb.h>
 
-#include "gtkpbinit.h"
+#include "gtkpbbinit.h"
 #include "gtkinterface.h"
 #include "audio.h"
 #include "gettext_macros.h"
@@ -54,7 +54,7 @@ gint timeout_callback(gpointer data)
 	if ((ipc_receive (msgbuffer, sizeof(msgbuffer))) == 0) {
 		switch (msg->action) {
 		case REGFAILED:
-			print_error (_("ERROR: Can't register client at server.\n"));
+			print_msg (PBB_ERR, _("Client registration denied.\n"));
 			gtk_main_quit();
 			break;
 		case CLIENTEXIT:
@@ -80,6 +80,8 @@ gint timeout_callback(gpointer data)
 				popup = POPUP_KBDILLU;
 			} else if ((taglist = find_tagitem(msg->taglist, TAG_EJECTCD))) {
 				popup = POPUP_CDROM;
+			} else if ((taglist = find_tagitem(msg->taglist, TAG_CRTMIRROR))) {
+				popup = POPUP_CRTMIRROR;
 			} else
 				break;  /* catch unknown warnings */
 
