@@ -42,6 +42,8 @@ struct layout_classic {
 	GtkWidget	*kbdillu_pixmap2;
 	GtkWidget	*cdrom_pixmap1;
 	GtkWidget	*cdrom_pixmap2;
+	GtkWidget	*mirror_pixmap1;
+	GtkWidget	*mirror_pixmap2;
 
 	int		current_popup;    /* popup currently prepared for */
 	GtkWidget	*hbox;
@@ -76,7 +78,9 @@ layout_classic_init (struct theme *td)
 		{KBDILLU,    "image1", theme_image, &te.kbdillu_pixmap1},
 		{KBDILLU,    "image2", theme_image, &te.kbdillu_pixmap2},
 		{CDROM,      "image1", theme_image, &te.cdrom_pixmap1},
-		{CDROM,      "image2", theme_image, &te.cdrom_pixmap2}
+		{CDROM,      "image2", theme_image, &te.cdrom_pixmap2},
+		{CRTMIRROR,  "image1", theme_image, &te.mirror_pixmap1},
+		{CRTMIRROR,  "image2", theme_image, &te.mirror_pixmap2}
 	};
 
 	for (n=0; n < sizeof(themedef) / sizeof(struct themeoption); n++)
@@ -136,6 +140,10 @@ layout_classic_exit (struct theme *td)
 			g_object_unref(te->cdrom_pixmap1);
 		if (te->cdrom_pixmap2 != NULL)
 			g_object_unref(te->cdrom_pixmap2);
+		if (te->mirror_pixmap1 != NULL)
+			g_object_unref(te->mirror_pixmap1);
+		if (te->mirror_pixmap2 != NULL)
+			g_object_unref(te->mirror_pixmap2);	
 		if (te->progressbar != NULL)
 			g_object_unref(te->progressbar);
 		if (te->message != NULL)
@@ -225,20 +233,20 @@ layout_classic_update (struct theme *td, GtkWidget *window, int popup, ...)
 		sprintf (message, "%d", arg0);
 		break;
 	case POPUP_VOLUME:
-	case POPUP_MUTE:
-		arg0			 = va_arg(list, int);
-		if (arg0 == 0) {
-			title		 = _("Mute");
-			pixmap_left  = te->mute_pixmap1;
-			pixmap_right = te->mute_pixmap2;
-		} else {
-			title		 = _("Volume");
-			pixmap_left  = te->volume_pixmap1;
-			pixmap_right = te->volume_pixmap2;
-		}
+		arg0		 = va_arg(list, int);
+		title		 = _("Volume");
+		pixmap_left  = te->volume_pixmap1;
+		pixmap_right = te->volume_pixmap2;
 		frac = (gdouble) arg0 / VOLUME_MAX;
 		sprintf (message, "%d", arg0);
 		break;
+	case POPUP_MUTE:
+		title		 = _("Mute");
+		pixmap_left  = te->mute_pixmap1;
+		pixmap_right = te->mute_pixmap2;
+		frac = 0.0;
+		sprintf (message, "0");
+		break;
 	case POPUP_NOAUDIO:
 		title		 = _("NOTICE");
 		pixmap_left  = te->noaudio_pixmap1;
@@ -311,6 +319,17 @@ layout_classic_update (struct theme *td, GtkWidget *window, int popup, ...)
 			break;
 		}
 		break;
+	case POPUP_CRTMIRROR:
+		pixmap_left  = te->mirror_pixmap1;
+		pixmap_right = te->mirror_pixmap2;
+		title		 = _("External Video");
+		
+		arg0 = va_arg(list, int) & 1;
+		if (arg0 == 0)
+			sprintf(message, _("External Video Output is OFF"));
+		else
+			sprintf(message, _("External Video Output is ON"));
+		break;
 	}
 
 	arg0 = layout_classic_get_popup_type(popup);
@@ -369,6 +388,7 @@ layout_classic_get_popup_type(int popup)
 	popup_types[POPUP_NOAUDIO]	= POPUP_TYPE_MESSAGE;
 	popup_types[POPUP_KBDILLU]	= POPUP_TYPE_PROGRESS;
 	popup_types[POPUP_CDROM]	= POPUP_TYPE_MESSAGE;
+	popup_types[POPUP_CRTMIRROR] = POPUP_TYPE_MESSAGE;
 
 	return popup_types[popup];
 }
