@@ -35,14 +35,15 @@ struct layout_macosx {
 	GtkWidget	*noaudio_pixmap;
 	GtkWidget	*kbdillu_pixmap;
 	GtkWidget	*cdrom_pixmap;
+	GtkWidget	*mirror_pixmap;
 
 	GdkPixbuf	*pbarempty_pixbuf;
 	GdkPixbuf	*pbarfull_pixbuf;
 
 	int		current_popup;    /* popup currently prepared for */
 	int		barwidth;         /* length of barimage */
-	GtkWidget	*frame1;
-	GtkWidget	*frame2;
+	GtkWidget	*align1;
+	GtkWidget	*align2;
 	GtkWidget	*barimage;
 	GtkWidget	*tpimage;
 	GtkWidget	*message;
@@ -75,6 +76,7 @@ layout_macosx_init (struct theme *td)
 		{NOAUDIO,    "image",     theme_image, &te.noaudio_pixmap},
 		{KBDILLU,    "image",     theme_image, &te.kbdillu_pixmap},
 		{CDROM,      "image",     theme_image, &te.cdrom_pixmap},
+		{CRTMIRROR,  "image",     theme_image, &te.mirror_pixmap},
 	};
 
 	/* This loop works only for the same datatype; in this case
@@ -141,6 +143,8 @@ layout_macosx_exit (struct theme *td)
 			g_object_unref(te->kbdillu_pixmap);
 		if (te->cdrom_pixmap != NULL)
 			g_object_unref(te->cdrom_pixmap);
+		if (te->mirror_pixmap != NULL)
+			g_object_unref(te->mirror_pixmap);
 
 		for(n=0; n < 3; n++)
 			if (te->tpmodes[n] != NULL)
@@ -158,7 +162,6 @@ layout_macosx_attach (struct theme *td, GtkWidget *window)
 
 	GdkPixbuf *bgpixbuf; 
 	GtkWidget *vbox;
-	GtkWidget *frame1, *frame2;
 	GtkWidget *align1, *align2;
 	GtkWidget *message;
 	int height = 0;
@@ -170,31 +173,22 @@ layout_macosx_attach (struct theme *td, GtkWidget *window)
 	vbox = gtk_vbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (window), vbox);
 
-	frame1 = gtk_frame_new(NULL);
 	align1 = gtk_alignment_new(0.5,0.7,0.0,0.0);
-	gtk_frame_set_shadow_type(GTK_FRAME(frame1), GTK_SHADOW_NONE);
 	gtk_box_pack_start (GTK_BOX (vbox), align1, TRUE, TRUE, 0);
-	gtk_container_add(GTK_CONTAINER(align1), frame1);
+	gtk_container_add(GTK_CONTAINER(align1), te->sleep_pixmap);
 	if (height)
-		gtk_widget_set_size_request(GTK_WIDGET(frame1), -1, (int) height * 0.7); 
+		gtk_widget_set_size_request(GTK_WIDGET(te->sleep_pixmap), -1, (int) height * 0.7); 
 
-	frame2 = gtk_frame_new(NULL);
 	align2 = gtk_alignment_new(0.5,0.0,0.0,0.0);
-	gtk_frame_set_shadow_type(GTK_FRAME(frame2), GTK_SHADOW_NONE);
 	gtk_box_pack_start (GTK_BOX (vbox), align2, TRUE, TRUE, 0);
-	gtk_container_add(GTK_CONTAINER(align2), frame2);
-
-	if (te->sleep_pixmap)
-		gtk_container_add(GTK_CONTAINER(frame1), te->sleep_pixmap);
-
 	message = gtk_label_new ("dummy");
 	gtk_widget_ref(message);
 	gtk_label_set_justify (GTK_LABEL(message), GTK_JUSTIFY_CENTER);
-		gtk_container_add(GTK_CONTAINER(frame2), message);
+	gtk_container_add(GTK_CONTAINER(align2), message);
 
 	te->current_popup	= POPUP_SLEEP;
-	te->frame1		= frame1;
-	te->frame2		= frame2;
+	te->align1		= align1;
+	te->align2		= align2;
 	te->message		= message;
 	te->pixmap		= te->sleep_pixmap;
 	return 0;
@@ -223,13 +217,13 @@ layout_macosx_update (struct theme *td, GtkWidget *window, int popup, ...)
 		frac	 = (gdouble) arg0 / BACKLIGHT_MAX;
 		break;
 	case POPUP_VOLUME:
-	case POPUP_MUTE:
 		arg0 = va_arg(list, int);
-		if (arg0 == 0)
-			pixmap = te->mute_pixmap;
-		else
-			pixmap = te->volume_pixmap;
 		frac = (gdouble) arg0 / VOLUME_MAX;
+		pixmap = te->volume_pixmap;
+		break;
+	case POPUP_MUTE:
+		pixmap = te->mute_pixmap;
+		frac = 0.0;
 		break;
 	case POPUP_NOAUDIO:
 		pixmap = te->noaudio_pixmap;
@@ -291,6 +285,14 @@ layout_macosx_update (struct theme *td, GtkWidget *window, int popup, ...)
 			break;
 		}
 		break;
+	case POPUP_CRTMIRROR:
+		arg0 = va_arg(list, int) & 1;
+		pixmap = te->mirror_pixmap;
+		if (arg0 == 0)
+			str = g_strdup_printf(label1line, te->textformat, _("Ext. Video off"));
+		else
+			str = g_strdup_printf(label1line, te->textformat, _("Ext. Video on"));	
+		break;
 	}
 
 	arg0 = layout_macosx_get_popup_type(popup);
@@ -298,29 +300,29 @@ layout_macosx_update (struct theme *td, GtkWidget *window, int popup, ...)
 
 	if (te->current_popup != popup) { /* popup changed? */
 		if (te->pixmap)
-			gtk_container_remove (GTK_CONTAINER(te->frame1), te->pixmap);
+			gtk_container_remove (GTK_CONTAINER(te->align1), te->pixmap);
 		if (pixmap)
-			gtk_container_add(GTK_CONTAINER(te->frame1), pixmap);
+			gtk_container_add(GTK_CONTAINER(te->align1), pixmap);
 		te->pixmap = pixmap;
 
 		if (arg0 != arg1) { /* popup type changed? */
 			switch (arg1) {  /* remove old widget not longer needed */
 			case POPUP_TYPE_PROGRESS:
-				gtk_container_remove (GTK_CONTAINER(te->frame2), te->barimage);
+				gtk_container_remove (GTK_CONTAINER(te->align2), te->barimage);
 				te->barimage = NULL;
 				break;
 			case POPUP_TYPE_MESSAGE:
-				gtk_container_remove (GTK_CONTAINER(te->frame2), te->message);
+				gtk_container_remove (GTK_CONTAINER(te->align2), te->message);
 				break;
 			case POPUP_TYPE_IMAGE:
 				if (te->tpimage) {
-					gtk_container_remove (GTK_CONTAINER(te->frame2), te->tpimage);
+					gtk_container_remove (GTK_CONTAINER(te->align2), te->tpimage);
 					te->tpimage = NULL;
 				}
 				break;
 			}
 			if (arg0 == POPUP_TYPE_MESSAGE)
-				gtk_container_add(GTK_CONTAINER(te->frame2), te->message);
+				gtk_container_add(GTK_CONTAINER(te->align2), te->message);
 		}
 		te->current_popup = popup;
 	}
@@ -339,9 +341,9 @@ layout_macosx_update (struct theme *td, GtkWidget *window, int popup, ...)
 				gdk_pixbuf_copy_area (te->pbarfull_pixbuf, 0, 0,
                 	l, y, tmppixbuf, 0, 0);
 				if (te->barimage)
-					gtk_container_remove (GTK_CONTAINER(te->frame2), te->barimage);
+					gtk_container_remove (GTK_CONTAINER(te->align2), te->barimage);
 				if ((te->barimage = gtk_image_new_from_pixbuf (tmppixbuf)))
-					gtk_container_add(GTK_CONTAINER(te->frame2), te->barimage);
+					gtk_container_add(GTK_CONTAINER(te->align2), te->barimage);
 				g_object_unref(tmppixbuf);
 			}
 		}
@@ -352,9 +354,9 @@ layout_macosx_update (struct theme *td, GtkWidget *window, int popup, ...)
 		break;
 	case POPUP_TYPE_IMAGE:
 		if (te->tpimage)
-			gtk_container_remove (GTK_CONTAINER(te->frame2), te->tpimage);
+			gtk_container_remove (GTK_CONTAINER(te->align2), te->tpimage);
 		te->tpimage = te->tpmodes[tpmode];
-		gtk_container_add(GTK_CONTAINER(te->frame2), te->tpimage);
+		gtk_container_add(GTK_CONTAINER(te->align2), te->tpimage);
 		break;
 	}
 	va_end(list);
@@ -374,6 +376,7 @@ layout_macosx_get_popup_type(int popup)
 	popup_types[POPUP_NOAUDIO]	= POPUP_TYPE_MESSAGE;
 	popup_types[POPUP_KBDILLU]	= POPUP_TYPE_PROGRESS;
 	popup_types[POPUP_CDROM]	= POPUP_TYPE_MESSAGE;
+	popup_types[POPUP_CRTMIRROR] = POPUP_TYPE_MESSAGE;
 
 	return popup_types[popup];
 }
